@@ -37,6 +37,6 @@ void Utils::setParentWindow(QWidget *w, const QString &parent_window)
 {
     if (parent_window.startsWith(QLatin1String("x11:"))) {
         w->setAttribute(Qt::WA_NativeWindow, true);
-        KWindowSystem::setMainWindow(w->windowHandle(), parent_window.midRef(4).toULongLong(nullptr, 16));
+        KWindowSystem::setMainWindow(w->windowHandle(), parent_window.mid(4).toULongLong(nullptr, 16));
     }
 }
